.. this is the default PG-RST stylesheet

.. style:: emphasis
   :class: italics

.. style:: strong
   :class: bold

.. style:: title_reference
   :class: italics

.. style:: option_argument
   :class: italics

.. style:: literal
   :class: monospaced

.. style:: subscript
   :class: subscript

.. style:: superscript
   :class: superscript

.. style:: title.document-title
   :class: x-large center
   :titlehack:

.. style:: title.topic-title
   :class: centerleft

.. style:: title.table-title
   :class: centerleft larger

.. figure and image styles for non-image formats

.. style:: figure
   :class: margin

.. style:: figure
   :formats: txt.* *.noimages
   :align: center
   :width: 80%

.. style:: image
   :formats: *.noimages
   
   .. container:: center image margin
   
      [image]


.. style:: image
   :formats: txt.*
   :display: none   

.. style:: caption.figure-caption
   :formats: -txt.*
   :class: centerleft italics margin

.. style:: caption.figure-caption
   :formats: txt.*
   :class: margin
   :before:  '[Illustration: '
   :after:   ']'

.. style:: legend
   :class: margin


.. default transition

.. style:: transition

   .. container:: center transition margin

      ――――

.. default attribution

.. style:: attribution
   :class: margin
   :before: '―― '

